@@ -13,13 +13,13 @@ class MessageType(Enum):
 class Message:
     message: str
     message_type: MessageType = MessageType.INFO
-    autoclose: int = None
+    auto_close: int = 5
 
     def __iter__(self):
         yield "message", self.message
         yield "type", self.message_type.value
-        if self.autoclose:
-            yield "autoclose", self.autoclose * 1000
+        if self.auto_close:
+            yield "auto_close", self.auto_close * 1000
 
 
 def info(message, **kwargs):
